@@ -53,6 +53,11 @@
 
 #include <math.h>
 
+struct _GstControlBindingPrivate
+{
+  GWeakRef object;
+};
+
 #define GST_CAT_DEFAULT control_binding_debug
 GST_DEBUG_CATEGORY_STATIC (GST_CAT_DEFAULT);
 
@@ -70,12 +75,7 @@ static void gst_control_binding_dispose (GObject * object);
 static void gst_control_binding_finalize (GObject * object);
 
 G_DEFINE_ABSTRACT_TYPE_WITH_CODE (GstControlBinding, gst_control_binding,
-    GST_TYPE_OBJECT, _do_init);
-
-struct _GstControlBindingPrivate
-{
-  GWeakRef object;
-};
+    GST_TYPE_OBJECT, G_ADD_PRIVATE (GstControlBinding) _do_init);
 
 enum
 {
@@ -92,8 +92,6 @@ gst_control_binding_class_init (GstControlBindingClass * klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GstControlBindingPrivate));
-
   gobject_class->constructor = gst_control_binding_constructor;
   gobject_class->set_property = gst_control_binding_set_property;
   gobject_class->get_property = gst_control_binding_get_property;
@@ -116,9 +114,7 @@ gst_control_binding_class_init (GstControlBindingClass * klass)
 static void
 gst_control_binding_init (GstControlBinding * binding)
 {
-  binding->ABI.abi.priv =
-      G_TYPE_INSTANCE_GET_PRIVATE (binding, GST_TYPE_CONTROL_BINDING,
-      GstControlBindingPrivate);
+  binding->ABI.abi.priv = gst_control_binding_get_instance_private (binding);
   g_weak_ref_init (&binding->ABI.abi.priv->object, NULL);
 }
 
@@ -149,7 +145,7 @@ gst_control_binding_constructor (GType type, guint n_construct_params,
               binding->name))) {
     GST_DEBUG_OBJECT (object, "  psec->flags : 0x%08x", pspec->flags);
 
-    /* check if this param is witable && controlable && !construct-only */
+    /* check if this param is writeable && controllable && !construct-only */
     if ((pspec->flags & (G_PARAM_WRITABLE | GST_PARAM_CONTROLLABLE |
                 G_PARAM_CONSTRUCT_ONLY)) ==
         (G_PARAM_WRITABLE | GST_PARAM_CONTROLLABLE)) {
@@ -157,7 +153,7 @@ gst_control_binding_constructor (GType type, guint n_construct_params,
     } else {
       GST_WARNING_OBJECT (object,
           "property '%s' on class '%s' needs to "
-          "be writeable, controlable and not construct_only", binding->name,
+          "be writeable, controllable and not construct_only", binding->name,
           G_OBJECT_TYPE_NAME (object));
     }
   } else {
@@ -176,8 +172,9 @@ gst_control_binding_dispose (GObject * object)
   GstControlBinding *self = GST_CONTROL_BINDING (object);
 
   /* we did not took a reference */
-  g_object_remove_weak_pointer ((GObject *) self->__object,
-      (gpointer *) & self->__object);
+  if (self->__object)
+    g_object_remove_weak_pointer ((GObject *) self->__object,
+        (gpointer *) & self->__object);
   self->__object = NULL;
   g_weak_ref_clear (&self->ABI.abi.priv->object);
 
